##  Video Tutorial for Microsoft Power BI and Tableau
In the following video tutorial, you can learn how to enable the OData integration with Microsoft Power BI and Tableau.
![Video thumbnail](https://cdnapisec.kaltura.com/html5/html5lib/v2.101/modules/KalturaSupport/thumbnail.php/p/1921661/uiconf_id/37285991/entry_id/1_fm040iv7/height/480?&flashvars\[parentDomain\]=https%3A%2F%2Fhelp.sap.com%2Fdocs%2Fleanix%2Fea%2Fsetting-up-odata-integration-with-business-intelligence-tools%3Fversion%3DCLOUD)
